#!/usr/bin/gnuplot

# disrupt.plt
# Calculation of collisional rates for Hildas, Trojans and main belt.
# Miroslav Broz (miroslav.broz@email.cz), Oct 15th 2008

print "\nHildas vs main belt collisions:"

V_imp = 4.78e3	# m/s; average impact velocity
Q_star = 1.e5	# J/kg; from scaling law (in gravity regime)
D_target = 100.	# km; target diameter

d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target	# projectile size needed (Bottke etal 2006)

n_project = 760.	# MB bodies larger than 20 km, according to (Bottke etal 2006)
n_target = 8.		# number of 100 km Hildas; two of them are just below 100 km limit

P_i = 0.62e-18	# km^-2 yr^-1; intrinsic collisional probability for HM collisions (Dahlgren 1998)

T_SS = 4.0e9	# yr; age of the Solar System (after LHB)

f_disrupt = P_i * D_target**2 * (n_project*n_target)
tau_disrupt = 1./f_disrupt
n_events = T_SS/tau_disrupt	# number of events during the existence of SS

print "D_target = ", D_target, " km"
print "d_disrupt = ", d_disrupt, " km"
print "f_disrupt = ", f_disrupt, " yr^-1"
print "tau_disrupt = ", tau_disrupt, " yr = ", tau_disrupt/1.e9, " Gyr"
print "n_events = ", n_events

########################################################################

print "\nHildas vs main belt, but for larger bodies:"

D_target = 200.	# km
Q_star = 4.e5	# J/kg; (it scales as D^2)

d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target

n_project = 160.	# MB bodies larger than ~65 km
n_target = 1.		# current number of 200 km Hildas

f_disrupt = P_i * D_target**2 * (n_project*n_target)
tau_disrupt = 1./f_disrupt
n_events = T_SS/tau_disrupt

print "D_target = ", D_target, " km"
print "d_disrupt = ", d_disrupt, " km"
print "f_disrupt = ", f_disrupt, " yr^-1"
print "tau_disrupt = ", tau_disrupt, " yr = ", tau_disrupt/1.e9, " Gyr"
print "n_events = ", n_events

########################################################################

print "\nmain belt vs main belt:"

V_imp = 5.28e3	# m/s
Q_star = 1.5e5	# J/kg; slightly larger than for H, because MB asteroids might be more resistant
D_target = 100.	# km

d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target

n_project = 760.	# MB bodies larger than ~20 km
n_target = 100.		# number of 100 km main belt asteroids
P_i = 3.10e-18		# km^-2 yr^-1; intrinsic collisional probability for MM collisions (Dahlgren 1998)

f_disrupt = P_i * D_target**2 * (n_project*n_target)
tau_disrupt = 1./f_disrupt
n_events = T_SS/tau_disrupt

print "D_target = ", D_target, " km"
print "d_disrupt = ", d_disrupt, " km"
print "f_disrupt = ", f_disrupt, " yr^-1"
print "tau_disrupt = ", tau_disrupt, " yr = ", tau_disrupt/1.e9, " Gyr"
print "n_events = ", n_events

########################################################################

print "\nTrojans vs Trojans:"

V_imp = 5.20e3	# m/s
Q_star = 1.e5	# J/kg

d_disrupt = (2*Q_star/V_imp**2)**(1./3.) * D_target

n_project = 464.	# number of Trojans larger than 20 km
n_target = 12.		# number of 100 km Trojans
P_i = 5.94e-18		# km^-2 yr^-1; intrinsic collisional probability for TT collisions (Dahlgren 1998)

f_disrupt = P_i * D_target**2 * (n_project*n_target)
tau_disrupt = 1./f_disrupt
n_events = T_SS/tau_disrupt

print "D_target = ", D_target, " km"
print "d_disrupt = ", d_disrupt, " km"
print "f_disrupt = ", f_disrupt, " yr^-1"
print "tau_disrupt = ", tau_disrupt, " yr = ", tau_disrupt/1.e9, " Gyr"
print "n_events = ", n_events

########################################################################

print ""


